#ifndef GCC_TM_H
#define GCC_TM_H
#define TARGET_CPU_DEFAULT (0)
#ifndef LIBC_GLIBC
# define LIBC_GLIBC 1
#endif
#ifndef LIBC_UCLIBC
# define LIBC_UCLIBC 2
#endif
#ifndef LIBC_BIONIC
# define LIBC_BIONIC 3
#endif
#ifndef LIBC_MUSL
# define LIBC_MUSL 4
#endif
#ifndef HEAP_TRAMPOLINES_INIT
# define HEAP_TRAMPOLINES_INIT 0
#endif
#ifndef TARGET_ARCH_DEFAULT
# define TARGET_ARCH_DEFAULT 0
#endif
#ifndef TARGET_DEFAULT_CTOR_DTOR
# define TARGET_DEFAULT_CTOR_DTOR 1
#endif
#ifdef IN_GCC
# include "options.h"
# include "insn-constants.h"
# include "config/elfos.h"
# include "config/newlib-stdint.h"
# include "config/nds32/nds32.h"
# include "config/nds32/elf.h"
# include "config/nds32/nds32_intrinsic.h"
# include "config/initfini-array.h"
#endif
#if defined IN_GCC && !defined GENERATOR_FILE && !defined USED_FOR_TARGET
# include "insn-flags.h"
#endif
#if defined IN_GCC && !defined GENERATOR_FILE
# include "insn-modes.h"
#endif
# include "defaults.h"
#endif /* GCC_TM_H */
